@@ -434,7 +434,7 @@ impl<R> JsonChecker<R> {
                 // Or change the state.
                 state => {
                     jc.state = state;
-                    if jc.end.is_none() && state == State::Ok {
+                    if jc.stack.len() == 1 && jc.end.is_none() && state == State::Ok {
                         jc.end = Some(jc.idx - 1); // If in state `OK` last state has already been poped. We must go back one char to be on the last character of the previous State.
                     }
                 }
